from distutils.core import setup
setup(
  name = 'edaviz',         
  packages = ['edaviz'],   
  version = '0.0.0',     
  license='',
  description = 'Exploratory Data Anlysis and Vizualisation',
  author = 'Tobias Krabel',                   
  author_email = 'tobiaskrabel@gmail.com',
  url = 'https://github.com/tkrabel/edaviz',
  download_url = 'https://github.com/tkrabel/edaviz/archive/0.0.0.tar.gz',
  keywords = ['vizualisation', 'exploration', 'data analysis', 'data vizualisation'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Programming Language :: Python :: 3.6',
  ],
)
